error_dict = {
    1: "EJECT_ERR",
    -709: "E_WRITE_FILE_STAT",
    -708: "E_READ_FILE_STAT",
    -707: "E_OPEN_FILE_STAT",
    -706: "CHECKENDORSEMENT_TEXT_CONVERT_ERROR",
    -705: "CHECKENDORSEMENT_MIRROR_ERROR",
    -704: "CHECKENDORSEMENT_BMP_FILE_ERROR",
    -703: "CHECKENDORSEMENT_ROTATE_ERROR",
    -702: "CHECKENDORSEMENT_MEMORY_ERROR",
    -701: "CHECKENDORSEMENT_PARAM_ERROR",
    -652: "TS5_AUTOALIGNMENT_FAULT",
    -651: "TS5_UNABLE_TO_LOAD_TS5DLL",
    -650: "TS5_SENSORBLOCKED",
    -649: "TS5_VOLTAGE_FAULT",
    -648: "TS2_ERR_OTHER",
    -647: "TS2_ERR_POCKETFULL",
    -646: "USER_HALTED",
    -645: "DP_UNABLE_TO_LOAD_DOCPDLL",
    -644: "TS2_ERR_FRANKER",
    -643: "TS4_UNABLE_TO_LOAD_TS4DLL",
    -642: "TS2_ERR_NO_MORE_DEVICES",
    -641: "TS2_ERR_ALREADY_INITIALIZED",
    -640: "TS2_ERR_DEVICE_NOT_CONNECTED",
    -639: "TS2_ERR_DEVICE_REINITIALIZATION_NEEDED",
    -638: "TS2_ERR_DLL_NOT_FOUND",
    -637: "TS2_ERR_INVALID_DLL",
    -636: "TS2_ERR_IO_DEVICE",
    -635: "TS2_ERR_DLL_INIT_FAILED",
    -634: "TS2_ERR_INVALID_PARAMETER",
    -633: "TS2_ERR_GEN_FAILURE",
    -632: "TS2_ERR_READ_FAULT",
    -631: "TS2_ERR_WRITE_FAULT",
    -630: "TS2_ERR_BAD_LENGTH",
    -629: "TS2_ERR_BAD_COMMAND",
    -628: "TS2_ERR_NOT_READY",
    -627: "TS2_ERR_BAD_UNIT",
    -626: "TS2_ERR_INVALID_DATA",
    -625: "TS2_ERR_INVALID_ACCESS",
    -624: "TS2_ERR_NOT_ENOUGH_MEMORY",
    -623: "TS2_ERR_INVALID_HANDLE",
    -622: "TS2_ERR_ACCESS_DENIED",
    -621: "TS2_ERR_FILE_NOT_FOUND",
    -620: "TS2_ERR_INVALID_FUNCTION",
    -619: "TS2_ERR_NOCONNECTION",
    -618: "TS2_ERR_OPENDEVICE",
    -617: "TS2_ERR_NOPORTAVAILABLE",
    -616: "TS2_ERR_DEVID_NOTVALID",
    -615: "TS2_ERR_GENERIC",
    -614: "E_POST",
    -613: "ERR_FEEDERSTAMP",
    -612: "ABORTED_CAL",
    -611: "UNKNOWN_CAL",
    -610: "NO_DATA_AVAIL",
    -609: "FORMAT_ERR",
    -608: "TS2_CALLBACK_FULL",
    -607: "IMAGE_TOO_LONG",
    -606: "ERR_CFGCREATION",
    -605: "NOT_SUPPORTED",
    -604: "E_HOSTSORT_TIMEOUT",
    -603: "E_ERR_FLASH",
    -602: "ERR_DESTSELECT",
    -601: "FONTFILE_ERR",
    -600: "E_OPEN_FONT_FILE",
    -558: "E_CFGFILEPATH",
    -557: "E_INIFILEPATH",
    -556: "E_EXCEEDS_MAX",
    -555: "E_BITS_PER_PIXEL",
    -554: "E_NO_DPI100_BW",
    -553: "E_NO_PRINT_HEAD",
    -552: "BAD_PARAM_ERR",
    -551: "MICRTIME_OUT",
    -550: "ACQTIME_OUT",
    -549: "CLRERR_ERR",
    -548: "GETSTATUS_ERR",
    -547: "PMEC_REJECTED",
    -546: "ACQPAR_REJECT",
    -545: "FAIL_ACQPAR",
    -544: "TMPCFG_REJECTED",
    -543: "FAIL_TMPCFG",
    -542: "EJECT_ERR",
    -541: "SETDOCPOS_ERR",
    -540: "ENDDOC_ERR",
    -530: "GETDOC_ERR",
    -529: "EE_UPDATE_ERR",
    -528: "EEREAD_ERR",
    -527: "LOADPRT_ERR",
    -526: "CLEARPRT_ERR",
    -525: "BAD_MICR",
    -524: "SCAN_ERRFLASH",
    -523: "NO_PRTHEAD",
    -522: "BADINSERT_ERR",
    -521: "MICRRD_ERR",
    -520: "ERR_WHITELEVCAL",
    -519: "ERR_BLACKLEVCAL",
    -518: "ERR_LIGHTCAL",
    -517: "SCSICMD_ERR",
    -516: "FAIL_PMEC",
    -510: "SCAN_GET_DOC",
    -319: "BUIC_ERROR_SET_MICR",
    -318: "BUIC_ERROR_SAME_FILENAME",
    -317: "BUIC_ERROR_SETTING_MICR_TAG",
    -316: "BUIC_ERROR_IMAGETYPE",
    -315: "BUIC_ERROR_GET_MICR",
    -244: "IJ_HEAD_NEAREMPTY",
    -243: "IJ_HEAD_EMPTY",
    -242: "SCAN_DOINGCLEAN_ERROR",
    -241: "ERRORLOWINK",
    -240: "SDH_USER_ERROR4",
    -239: "SDH_USER_ERROR3",
    -238: "SDH_USER_ERROR2",
    -237: "SDH_USER_ERROR1",
    -236: "SDH_FRAUD_ERROR",
    -235: "FIRMWARE_OUT_DATE",
    -234: "B1000_USI_ROTATE",
    -233: "B1000_DISK_WRITE",
    -232: "B1000_USI_COMPRESS",
    -231: "B1000_ROTATE",
    -230: "B1000_GRAYFILE",
    -227: "MICR_PARSE_ERROR",
    -224: "SCAN_MEM_NOT_AVAILABLE",
    -223: "SCAN_MEM_ALLOC",
    -222: "B1000_DISK_READ",
    -220: "SCAN_PAPER_JAM",
    -219: "SCAN_DANGEROUS",
    -218: "TMPFILE_ERR",
    -217: "SCAN_DOUBLE_FEED",
    -216: "SCAN_NO_FEED",
    -215: "SCAN_NO_LOOP",
    -214: "B1000_NO_CFG",
    -213: "B1000_GEN_ERR",
    -212: "SCAN_NO_CHEQUES",
    -211: "B1000_SEND_CONFIG",
    -210: "B1000_END_OF_JOB",
    -209: "SCAN_MAGN_READER",
    -208: "B1000_DMA_TRANSFER",
    -207: "SCAN_TIME_OUT",
    -206: "SCAN_SCSI_ACQ",
    -205: "B1000_GET_DOC",
    -204: "B1000_BADGE",
    -203: "SCAN_CLR_ERR",
    -202: "SCAN_START_ACQ",
    -126: "E_NO_DCC_SCANNER",
    -125: "E_NO_SCANNER",
    -124: "BUIC_NOT_INIT",
    -123: "E_TS400_NO_INIT",
    -122: "E_STRING_TOO_LONG",
    -120: "E_OPEN_BMP_FILE",
    -114: "BUIC_ERROR_PREVIOUS_INIT",
    -113: "BUIC_ERROR_MEMORY_DEALLOC",
    -112: "BUIC_DISPLAY_IMAGE",
    -111: "BUIC_CLOSE_WINDOW",
    -110: "BUIC_CREATE_WINDOW",
    -109: "BUIC_OPEN_WINDOW",
    -108: "BUIC_INV_WINDOW",
    -107: "BUIC_ERROR_FILE_IO",
    -106: "BUIC_ERROR_MEMORY_ALLOC",
    -105: "SCAN_DISK_OPEN",
    -104: "BUIC_ERROR_IMAGE_TYPE",
    -103: "BUIC_ERROR_BADFILENAME",
    -102: "BUIC_ERROR_BADPARAM",
    -101: "BUIC_ERROR_BADJOB",
    -100: "BUIC_ERROR_NOINIT",
    -5: "BUIC_ERROR_NOMANAGER",
    -4: "BUIC_ERROR_ILLEGALMODE",
    -3: "BUIC_ERROR_OLDMANAGER",
    -2: "BUIC_ERROR_NODEVICE",
    -1: "BUIC_ERROR",
    62000: "H_NO_CHEQUES",
    62001: "H_PAPER_JAM",
    62002: "H_NO_FEED",
    62003: "H_MICRRD_ERR",
    62004: "H_DANGEROUS",
    62005: "H_NO_LOOP",
    62006: "H_BADINSERT_ERR",
    62007: "H_ACQTIME_OUT",
    62008: "H_MICRTIME_out",
    62009: "H_EXTRDTIME_out",
    62010: "H_ERR_FEEDERSTAMP",
    62020: "H_NO_SCSI_DEVICE",
    62021: "H_NO_PRTHEAD",
    62022: "H_MEM_ALLOC",
    62023: "H_MEM_NOT_AVAILABLE",
    62024: "H_ERRFLASH",
    62025: "H_DISK_OPEN",
    62026: "H_ERR_CFGCREATION",
    62027: "H_INVALID_PARAM",
    62028: "H_IMAGE_TOO_LONG",
    62029: "H_FONTFILE_ERR",
    62030: "H_FORMAT_ERR",
    62031: "H_NO_DATA_AVAIL",
    62040: "H_UNKNOWN_CAL",
    62041: "H_ABORTED_CAL",
    62042: "H_ERR_LIGHTCAL",
    62043: "H_ERR_BLACKLEVCAL",
    62044: "H_ERR_WHITELEVCAL",
    62100: "H_GETSTATUS_ERR",
    62101: "H_CLRERR_ERR",
    62102: "H_FAIL_TMPCFG",
    62103: "H_FAIL_ACQPAR",
    62104: "H_FAIL_PMEC",
    62105: "H_ACQPAR_REJECT",
    62106: "H_PMEC_REJECTED",
    62107: "H_TMPCFG_REJECTED",
    62108: "H_GETDOC_ERR",
    62109: "H_EJECT_ERR",
    62110: "H_SETDOCPOS_ERR",
    62111: "H_ENDDOC_ERR",
    62112: "H_EEUPDATE_ERR",
    62113: "H_EEREAD_ERR",
    62114: "H_LOADPRT_ERR",
    62115: "H_CLEARPRT_ERR",
    62116: "H_SCSICMDTIME_out",
    62117: "H_SCSICMD_ERR",
    62118: "H_SCSI_ACQ",
    62119: "H_ERR_DESTSELECT",
}
